@@ -26,7 +26,7 @@ class RescissionWorkflow:
         target_admission_date: datetime = None,
         code_reason_rescission: int = None,
         activity_name: str = None,
-        recision_time: datetime = None,
+        rescission_time: datetime = None,
         face_to_face_communication: str = None,
         email_corp_witness_1: str = None,
         email_corp_witness_2: str = None,
@@ -69,7 +69,7 @@ class RescissionWorkflow:
                 else None,
                 "code_reason_rescission": code_reason_rescission,
                 "activity_name": activity_name,
-                "recision_time": recision_time,
+                "rescission_time": rescission_time,
                 "face_to_face_communication": face_to_face_communication,
                 "email_corp_witness_1": email_corp_witness_1,
                 "email_corp_witness_2": email_corp_witness_2,
